#import <Foundation/Foundation.h>
#import "AllTests.h"

#import "UnzipTestCase.h"
#import "TarTestCase.h"
#import "RarTestCase.h"
#import "PreferencesTestCase.h"
#import "LhaTestCase.h"
#import "SevenZipTestCase.h"

@implementation AllTests : NSObject

+ (TestSuite *)suite
{
    TestSuite *suite = [TestSuite suiteWithName:@"All Tests"];
    [suite addTest:[TestSuite suiteWithClass:[PreferencesTestCase class]]];
	[suite addTest:[TestSuite suiteWithClass:[UnzipTestCase class]]];
	[suite addTest:[TestSuite suiteWithClass:[TarTestCase class]]];
	[suite addTest:[TestSuite suiteWithClass:[RarTestCase class]]];
	[suite addTest:[TestSuite suiteWithClass:[LhaTestCase class]]];
	[suite addTest:[TestSuite suiteWithClass:[SevenZipTestCase class]]];
    
    return suite;
}

@end
